@@ -1,14 +1,20 @@
-from ftw.simplelayout.aliasblock.contents.interfaces import IAliasBlock
-from plone import api
-from plone.app.layout.viewlets.common import ViewletBase
 from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
-from zope.component import queryMultiAdapter
+from ftw.simplelayout.aliasblock.contents.interfaces import IAliasBlock
+from plone.app.layout.viewlets.common import ViewletBase
+from plone.registry.interfaces import IRegistry
+from zope.component import getUtility
 
 
 def geo_settings_installed():
-    version = api.portal.get().portal_setup.getLastVersionForProfile('collective.geo.settings:default')
-    return version != 'unknown'
+    has_settings = True
+    try:
+        from collective.geo.settings.interfaces import IGeoSettings
+        getUtility(IRegistry).forInterface(IGeoSettings)
+    except (KeyError, ImportError):
+        # Getting the record migh yield a KeyError
+        has_settings = False
 
+    return has_settings
 
 
 class AliasBlockFormViewlet(ViewletBase):
@@ -19,5 +25,4 @@ class AliasBlockFormViewlet(ViewletBase):
 
         is_aliasblock = IAliasBlock.providedBy(self.context)
         is_aliasblock_add_form = self.view.__name__ == 'ftw.simplelayout.AliasBlock'
-
         self.do_render_mapwidget = (is_aliasblock or is_aliasblock_add_form) and geo_settings_installed()
