@@ -21,13 +21,16 @@
     }
   }
 
+  function inAliasblock(idx, element) {
+    return $(element).closest('.sl-alias-block').length === 0;
+  }
+
   function initDropZone(element) {
     var target = $(element).find('.filedropzone');
     if (target.length === 0) {
       return;
     }
     var button = target.next();
-
     target.dropzone({
       url: target.data('endpoint'),
       autoProcessQueue: false,
@@ -41,8 +44,15 @@
           event.preventDefault();
           dropzoneObj.processQueue();
         });
-        dropzoneObj.on("success", function() {
-           dropzoneObj.options.autoProcessQueue = true;
+        dropzoneObj.on("success", function(file) {
+          dropzoneObj.removeFile(file);
+          dropzoneObj.options.autoProcessQueue = true;
+        });
+        dropzoneObj.on("error", function(file, response, xhr) {
+          if (xhr !== null) {
+            $(file.previewElement).addClass("dz-error").find('.dz-error-message').text(response.error); 
+          }
+          dropzoneObj.options.autoProcessQueue = true;
         });
         dropzoneObj.on('addedfile', function (file) {
           var timestamp = new Date().getTime();
@@ -76,17 +86,17 @@
       var payLoad = { uid: block.represents };
       var configRequest = $.post('./sl-ajax-reload-block-view', { "data": JSON.stringify(payLoad) });
       configRequest.done(function(blockContent) {
+        dropzoneObj.options.autoProcessQueue = false;
+        var dropzone = target.parents(".sl-block").find('.dropzonewrapper').detach();
         block.content(blockContent);
-        initDropZone(block.element);
+        block.element.find('.dropzonewrapper').replaceWith(dropzone);
       });
     });
   }
 
   $(document).ready(function(){
-    $('.sl-block').each(function(){
-      if ($(this).closest('.sl-alias-block').length === 0) {
-        initDropZone(this);
-      }
+    $('.sl-block').filter(inAliasblock).each(function(){
+      initDropZone(this);
     });
   });
 
@@ -188,16 +198,13 @@
       var state = {};
       $(".sl-simplelayout").each(function(manIdx, manager) {
         state[manager.id] = [];
-        $(".sl-layout", manager).each(function(layIdx, layout) {
-          if ($(layout).closest('.sl-alias-block').length === 1) { return; }
+        $(".sl-layout", manager).filter(inAliasblock).each(function(layIdx, layout) {
           state[manager.id][layIdx] = {};
           state[manager.id][layIdx].cols = [];
           state[manager.id][layIdx].config = $(layout).data().object.config();
-          $(".sl-column", layout).each(function(colIdx, column) {
-            if ($(column).closest('.sl-alias-block').length === 1) { return; }
+          $(".sl-column", layout).filter(inAliasblock).each(function(colIdx, column) {
             state[manager.id][layIdx].cols[colIdx] = { blocks: [] };
-            const blocks = $(".sl-block", column).filter(function(index, element){ return $(element).closest('.sl-alias-block').length === 0 })
-            blocks.each(function(bloIdx, block) {
+            $(".sl-block", column).filter(inAliasblock).each(function(bloIdx, block) {
               state[manager.id][layIdx].cols[colIdx].blocks[bloIdx] = { uid: $(block).data().represents };
             });
           });
