@@ -1,3 +1,4 @@
+from ftw.simplelayout.utils import IS_PLONE_5
 from ftw.upgrade import UpgradeStep
 
 
@@ -6,4 +7,5 @@ class FixContenttypeJqueryDependency(UpgradeStep):
     """
 
     def __call__(self):
-        self.install_upgrade_profile()
+        if IS_PLONE_5:
+            self.install_upgrade_profile()
